Resolve a free-form query to coordinates and metadata using the OpenStreetMap Nominatim service.
Value
A tibble with columns display_name, lat,
lon, osm_type, osm_id and class.
Resolve a free-form query to coordinates and metadata using the OpenStreetMap Nominatim service.
A tibble with columns display_name, lat,
lon, osm_type, osm_id and class.